@@ -157,11 +157,11 @@ class StickProtocol():
         try:
             member = self.User.objects.get(id=memberId)
         except:
-            print('GETTING USING ONETIMEID')
             member = self.User.objects.get(oneTimeId=memberId)
 
         # You need to check whether the user is authorized to fetch that SenderKey
         authorized = False
+        exists = True
         if user in member.blocked.all():  # A blocked user is not authorized
             return {'authorized': authorized}
         if isInvitation:  # An invited user is authorized
@@ -177,7 +177,10 @@ class StickProtocol():
                 if group in user.groups.all():  # A group member is authorized
                     authorized = True
             else:
-                party = Party.objects.get(id=stickId[:36])
+                party = Party.objects.filter(id=stickId[:36]).first()
+                if not party:
+                    exists = False
+                    return {'exists': exists}
                 # A user connected with another user should be authorized
                 if party.user and (user in party.user.connections.all() or user.phone in party.user.contacts):
                     authorized = True
@@ -213,7 +216,7 @@ class StickProtocol():
             if not PendingKey.objects.filter(user=user, stickId=stickId).exists():
                 PendingKey.objects.create(user=user, owner=member, stickId=stickId)
                 phone = member.phone
-        return {'authorized': authorized, 'senderKey': key, 'phone': phone}
+        return {'authorized': authorized, 'senderKey': key, 'phone': phone, 'exists': exists}
 
     def get_standard_sender_keys(self, data, user, group):
         """
@@ -230,7 +233,7 @@ class StickProtocol():
             key = None
             if senderKey:
                 key = senderKey.key
-                senderKey.delete()
+                # senderKey.delete()
             senderKeys[id] = key
         return {'authorized': True, 'senderKeys': senderKeys}
 
